@@ -526,7 +526,7 @@ def pytest_terminal_summary(terminalreporter, exitstatus, config):
     if settings.ONLY_LINUX_NOTIFICATION:
         if "linux" not in platform.platform().lower():
             return
-    for webhook in settings.LARK_WEBHOOKS:
+    for webhook in settings.LARK_WEBHOOKS.get(CONTEXT.get("env")):
         LarkUtil(webhook).send_test_report(
             total=total,
             passed=passed,
@@ -537,7 +537,6 @@ def pytest_terminal_summary(terminalreporter, exitstatus, config):
             env=CONTEXT.get("env")
         )
 
-
 def pytest_exception_interact(node, call, report):
     """
     用例执行抛出异常时，将异常记录到日志
