@@ -18,11 +18,6 @@ class RequestException(Exception):
     ...
 
 
-class ResponseException(Exception):
-    """响应异常"""
-    ...
-
-
 class MysqlDBError(Exception):
     """自定义 Redis 异常"""
     pass
