@@ -91,6 +91,7 @@ class GlobalAttribute(object):
             self.set(k, v)
 
     def set_from_yaml(self, filename, env, app=None):
+        file = None
         try:
             file = os.path.join(ROOT_DIR, filename)
             if not os.path.exists(file):
@@ -99,9 +100,11 @@ class GlobalAttribute(object):
             self.set_from_dict(dict(Box().from_yaml(filename=file, Loader=NoDatesSafeLoader).get(env)), app)
         except BoxError as e:
             logger.error(f"{file}文件内容不是字典类型:{e}")
-            traceback.print_exc()
             pytest.exit(ExitCode.CONTEXT_YAML_DATA_FORMAT_ERROR)
 
+        except Exception as e:
+            logger.warning(f"{filename}获取{env}环境信息异常: {e}")
+
     def delete(self, key):
         delattr(self, key)
 
